@@ -221,9 +221,9 @@ L<Mojo::Headers> implements the following attributes.
   my $size = $headers->max_line_size;
   $headers = $headers->max_line_size(1024);
 
-Maximum line size in bytes, defaults to the value of C<MOJO_MAX_LINE_SIZE> or
-C<10240>. Note that this attribute is EXPERIMENTAL and might change without
-warning!
+Maximum line size in bytes, defaults to the value of the
+C<MOJO_MAX_LINE_SIZE> environment variable or C<10240>. Note that this
+attribute is EXPERIMENTAL and might change without warning!
 
 =head1 METHODS
 
